InvalidStateError

Enum InvalidStateError 

#[non_exhaustive]
pub enum InvalidStateError {
Show 15 variants NoCipherSuiteSelected, NoCipherSuite, NoClientRandom, NoServerRandom, NoSharedSecretForHandshakeKeyDerivation, NoServerHandshakeTrafficSecret, NoServerHandshakeTrafficSecretForFinished, NoClientHandshakeTrafficSecret, NoClientHandshakeTrafficSecretForFinished, NoHandshakeSecretForApplicationKeyDerivation, NoActiveKeyExchange, NoCurrentAppSendKeysForKeyUpdate, NoCurrentAppRecvKeysForKeyUpdate, ExporterMasterSecretNotDerived, ExtendedMasterSecretSessionHashMissing,
}
Fine-grained reason for an Error::InvalidState.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NoCipherSuiteSelected

No cipher suite has been selected for the connection.



NoCipherSuite

A cipher suite was required but not available.



NoClientRandom

The client random was required but not available.



NoServerRandom

The server random was required but not available.



NoSharedSecretForHandshakeKeyDerivation

The handshake key schedule was used before a shared secret existed.



NoServerHandshakeTrafficSecret

The server handshake traffic secret was required but not available.



NoServerHandshakeTrafficSecretForFinished

The server handshake traffic secret was required to verify or create Finished.



NoClientHandshakeTrafficSecret

The client handshake traffic secret was required but not available.



NoClientHandshakeTrafficSecretForFinished

The client handshake traffic secret was required to verify or create Finished.



NoHandshakeSecretForApplicationKeyDerivation

Application traffic keys were requested before the handshake secret existed.



NoActiveKeyExchange

A key exchange was required but no exchange was active.



NoCurrentAppSendKeysForKeyUpdate

A DTLS 1.3 key update was requested before current send keys existed.



NoCurrentAppRecvKeysForKeyUpdate

A DTLS 1.3 peer key update was processed before current receive keys existed.



ExporterMasterSecretNotDerived

Exported keying material was requested before the exporter secret was derived.



ExtendedMasterSecretSessionHashMissing

Extended master secret was negotiated, but the session hash was not captured.