pub struct Dtls12CipherSuite(/* private fields */);Expand description
Supported TLS 1.2 cipher suites for DTLS.
Implementations
Sourceimpl Dtls12CipherSuite
impl Dtls12CipherSuite
Sourcepub const ECDHE_ECDSA_AES256_GCM_SHA384: Self
pub const ECDHE_ECDSA_AES256_GCM_SHA384: Self
ECDHE with ECDSA authentication, AES-256-GCM, SHA-384.
Sourcepub const ECDHE_ECDSA_AES128_GCM_SHA256: Self
pub const ECDHE_ECDSA_AES128_GCM_SHA256: Self
ECDHE with ECDSA authentication, AES-128-GCM, SHA-256.
Sourcepub const ECDHE_ECDSA_CHACHA20_POLY1305_SHA256: Self
pub const ECDHE_ECDSA_CHACHA20_POLY1305_SHA256: Self
ECDHE with ECDSA authentication, ChaCha20-Poly1305, SHA-256.
Sourcepub const PSK_AES128_CCM_8: Self
pub const PSK_AES128_CCM_8: Self
PSK with AES-128-CCM-8 (8-byte tag), SHA-256.
Sourcepub const fn from_u16(value: u16) -> Self
pub const fn from_u16(value: u16) -> Self
Convert the 16-bit IANA value to a Dtls12CipherSuite.
Sourcepub const fn is_unknown(&self) -> bool
pub const fn is_unknown(&self) -> bool
Returns true if this is not a known DTLS 1.2 cipher suite wire value.
Sourcepub fn parse(input: &[u8]) -> IResult<&[u8], Dtls12CipherSuite>
pub fn parse(input: &[u8]) -> IResult<&[u8], Dtls12CipherSuite>
Parse a Dtls12CipherSuite from network byte order.
Sourcepub fn verify_data_length(&self) -> usize
pub fn verify_data_length(&self) -> usize
Length in bytes of verify_data for Finished MACs.
Sourcepub fn as_key_exchange_algorithm(&self) -> KeyExchangeAlgorithm
pub fn as_key_exchange_algorithm(&self) -> KeyExchangeAlgorithm
The key exchange algorithm family for this cipher suite.
Sourcepub const fn all() -> &'static [Dtls12CipherSuite; 4]
pub const fn all() -> &'static [Dtls12CipherSuite; 4]
All supported cipher suites in server preference order.
Sourcepub fn compatible_with_certificate(
cert_type: SignatureAlgorithm,
) -> &'static [Dtls12CipherSuite; 3]
pub fn compatible_with_certificate( cert_type: SignatureAlgorithm, ) -> &'static [Dtls12CipherSuite; 3]
Cipher suites compatible with a given certificate’s signature algorithm.
Sourcepub fn hash_algorithm(&self) -> HashAlgorithm
pub fn hash_algorithm(&self) -> HashAlgorithm
The hash algorithm used by this cipher suite.
Sourcepub fn signature_algorithm(&self) -> Option<SignatureAlgorithm>
pub fn signature_algorithm(&self) -> Option<SignatureAlgorithm>
The signature algorithm associated with the suite’s key exchange.
Returns None for PSK cipher suites (no signature authentication).
Sourcepub fn is_supported(&self) -> bool
pub fn is_supported(&self) -> bool
Returns true if this cipher suite is supported by this implementation.
Sourcepub const fn supported() -> &'static [Dtls12CipherSuite; 4]
pub const fn supported() -> &'static [Dtls12CipherSuite; 4]
Supported DTLS 1.2 cipher suites in server preference order.